@@ -26,10 +26,10 @@
 #include <qstring.h>
 
 #include "cdinfo.h"
-
+#include <kdemacros.h>
 namespace KCDDB
 {
-  class Cache
+  class KDE_EXPORT Cache
   {
     public:
 
@@ -42,10 +42,14 @@ namespace KCDDB
 
       static CDInfoList lookup( const QString & );
       static void store( const CDInfoList & );
+      // KDE4: Should probably take a TrackOffsetList too, so
+      // the list can be stored in the file, and we can make
+      // sure the discid is correct (had to do the same fix in
+      // both kscd and kaudiocreator)
       static void store( const CDInfo & );
 
     private:
-      static QString fileName( const CDInfo &, const QString &cacheDir );
+      static QString fileName( const QString &category, const QString& discid, const QString &cacheDir );
   };
 }
 
